@@ -90,7 +90,7 @@ class RexcelWorkbook:
         if comment_column is not None:
             columns.append(comment_column)
         for j, header in enumerate(columns):
-            if not header or header == 'index':
+            if not header or header.lower() in ('index',) or 'unnamed:' in header.lower():
                 continue
             wks.write(
                 f"{self.get_column_letter(j)}{row_number + 1}",
@@ -154,6 +154,7 @@ class RexcelWorkbook:
                     col_number + offset,
                     ""
                 )
+                offset += 1
             row_number += 1
         if conditional_formatting:
             for format_range, config in conditional_formatting.items():
